==> v1.0.0.tar.gz: panel_lib/DOCS.md <==
# Panel_lib docs

## 1. Panel structure

A panel is a custom object made of 2 HUD elements, the title and the background, plus a group of two sub-elements: the text and the images. Picture the background as the container of all the things you want to showcase in your HUD. Those things go in the sub-elements.  

### 1.1. Declaration
To declare a new panel, simply do  
`local panel = Panel:new({parameters})`  
  
The parameters it takes are the following:
* `player`: the player to assign the panel to
* `position`: the panel position (as in any other HUD)
* `alignment`: same
* `bg`: the picture to put in the background
* `bg_scale`: its scaling
* `title`: the default text
* `title_alignment`
* `title_offset`
* `title_color`
* `sub_img_elems`: (table) whatever image to add to the panel
* `sub_txt_elems`: (table) whatever text to add to the panel

### 1.2. Sub-elements
Sub-elements are HUDs added on top of the main container, sharing the same position. This means two things:  
1. As a HUD, they take the same parameters a HUD takes. They are clones respectively of the background and the title, so if you skip some parameter, they'll keep their reference default value.
2. If you wanna move them around, you must tweak the offset, **NOT** the position. If you change the position, they may look fine in a screen resolution, but not in another. In order to prevent it, `panel_lib` automatically overrides the position with the panel's.

Have a look at [the example file](https://gitlab.com/zughy-friends-minetest/panel_lib/-/blob/master/panel.example) to see a complete panel declaration.

## 2. Configuration

Install it as any other mod `¯\_(ツ)_/¯`

## 2.1. Functions

* `new({params})`: creates a new panel
* `show()`: makes the panel appear
* `hide()`: makes the panel disappear (but it's still assigned to the player)
* `remove()`: deletes it
* `update(panel_params, txt_elems, img_elems)`: updates only the mentioned parameters. For instance, calling  

```
panel:update(nil, nil, {my_custom_img = {
      text = "pic2.png"
    })
```
updates just the text of the sub-element `my_custom_img`.  

There is also a getter, to obtain the panel associated with a player
* `panel_lib.get_panel(player_name)`

## 3. Collaborating
Something's wrong? Feel free to open an issue, go for a merge request and whatnot. I'd really appreciate it :)

## 4. About the author(s)
I'm Zughy (Marco), a professional Italian pixel artist who fights for FOSS and digital ethics. If this library spared you a lot of time and you want to support me somehow, please consider donating on [LiberaPay](https://it.liberapay.com/EticaDigitale/) directly to my educational Italian project (because not everyone speaks English and Italian media don't talk about these topics much). Also, this project wouldn't have been possible if it hadn't been for some friends who helped me testing through: `SonoMichele`, `_Zaizen_` and `Xx_Crazyminer_xX`

==> v1.0.1.tar.gz: panel_lib/DOCS.md <==
# Panel_lib docs

## 1. Panel structure

A panel is a custom object made of 2 HUD elements, the title and the background, plus a group of two sub-elements: the text and the images. Picture the background as the container of all the things you want to showcase in your HUD. Those things go in the sub-elements.  

### 1.1. Declaration
To declare a new panel, simply do  
`local panel = Panel:new({parameters})`  
  
The parameters it takes are the following:
* `player`: the player to assign the panel to
* `position`: the panel position (as in any other HUD)
* `alignment`: same
* `bg`: the picture to put in the background
* `bg_scale`: its scaling
* `title`: the default text
* `title_alignment`
* `title_offset`
* `title_color`
* `sub_img_elems`: (table) whatever image to add to the panel
* `sub_txt_elems`: (table) whatever text to add to the panel

### 1.2. Sub-elements
Sub-elements are HUDs added on top of the main container, sharing the same position. This means two things:  
1. As a HUD, they take the same parameters a HUD takes. They are clones respectively of the background and the title, so if you skip some parameter, they'll keep their reference default value.
2. If you wanna move them around, you must tweak the offset, **NOT** the position. If you change the position, they may look fine in a screen resolution, but not in another. In order to prevent it, `panel_lib` automatically overrides the position with the panel's.

Have a look at [the example file](https://gitlab.com/zughy-friends-minetest/panel_lib/-/blob/master/panel.example) to see a complete panel declaration.

## 2. Configuration

Install it as any other mod `¯\_(ツ)_/¯`

## 2.1. Functions

* `new({params})`: creates a new panel
* `show()`: makes the panel appear
* `hide()`: makes the panel disappear (but it's still assigned to the player)
* `remove()`: deletes it
* `update(panel_params, txt_elems, img_elems)`: updates only the mentioned parameters. For instance, calling  

```
panel:update(nil, nil, {my_custom_img = {
      text = "pic2.png"
    })
```
updates just the text of the sub-element `my_custom_img`.  

There is also a getter, to obtain the panel associated with a player
* `panel_lib.get_panel(player_name)`

## 3. Collaborating
Something's wrong? Feel free to:
* open an [issue](https://gitlab.com/zughy-friends-minetest/panel_lib/-/issues)
* submit a merge request. In this case, PLEASE, do follow milestones and my [coding guidelines](https://cryptpad.fr/pad/#/2/pad/view/-l75iHl3x54py20u2Y5OSAX4iruQBdeQXcO7PGTtGew/embed/). I won't merge features for milestones that are different from the upcoming one (if it's declared), nor messy code
* contact me on the [Minetest Forum](https://forum.minetest.net/memberlist.php?mode=viewprofile&u=26472)

I'd really appreciate it :)

## 4. About the author(s)
I'm Zughy (Marco), a professional Italian pixel artist who fights for FOSS and digital ethics. If this library spared you a lot of time and you want to support me somehow, please consider donating on [LiberaPay](https://liberapay.com/Zughy/). Also, this project wouldn't have been possible if it hadn't been for some friends who helped me testing through: `SonoMichele`, `_Zaizen_` and `Xx_Crazyminer_xX`
